==> convertall_0.5.2.orig.tar.gz: ConvertAll/source/optiondefaults.py <==
#!/usr/bin/env python

#****************************************************************************
# optiondefaults.py, provides defaults for program options
#
# ConvertAll, a units conversion program
# Copyright (C) 2006, Douglas W. Bell
#
# This is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License, either Version 2 or any later
# version.  This program is distributed in the hope that it will be useful,
# but WITTHOUT ANY WARRANTY.  See the included LICENSE file for details.
#*****************************************************************************


defaultList = [
    "# Options for the ConvertAll unit conversion program",
    "#",
    "# All options are set from within the program,",
    "# editing here is not recommended",
    "#",
    "UseDefaultColors    yes",
    "BackgroundR         255",
    "BackgroundG         255",
    "BackgroundB         255",
    "ForegroundR         0",
    "ForegroundG         0",
    "ForegroundB         0",
    "#",
    "DecimalPlaces       8",
    "SciNotation         no",
    "FixedDecimals       no",
    "ShowOpButtons       yes",
    "RecentUnits         8",
    "#",
    "MainDlgXSize        0",
    "MainDlgYSize        0",
    "MainDlgXPos         0",
    "MainDlgYPos         0",
    "FinderXSize         0",
    "FinderYSize         0",
    "FinderXPos          0",
    "FinderYPos          0",
    "#",
    "RecentUnit1          ",
    "RecentUnit2          ",
    "RecentUnit3          ",
    "RecentUnit4          ",
    "RecentUnit5          ",
    "RecentUnit6          ",
    "RecentUnit7          ",
    "RecentUnit8          "]

==> convertall_0.6.1.orig.tar.gz: ConvertAll/source/optiondefaults.py <==
#!/usr/bin/env python3

#****************************************************************************
# optiondefaults.py, provides defaults for program options
#
# ConvertAll, a units conversion program
# Copyright (C) 2015, Douglas W. Bell
#
# This is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License, either Version 2 or any later
# version.  This program is distributed in the hope that it will be useful,
# but WITTHOUT ANY WARRANTY.  See the included LICENSE file for details.
#*****************************************************************************


defaultList = [
    "# Options for the ConvertAll unit conversion program",
    "#",
    "# All options are set from within the program,",
    "# editing here is not recommended",
    "#",
    "UseDefaultColors    yes",
    "BackgroundR         255",
    "BackgroundG         255",
    "BackgroundB         255",
    "ForegroundR         0",
    "ForegroundG         0",
    "ForegroundB         0",
    "#",
    "DecimalPlaces       8",
    "Notation            general",
    "ShowOpButtons       yes",
    "RecentUnits         8",
    "LoadLastUnit        no",
    "ShowStartupTip      yes",
    "#",
    "MainDlgXSize        0",
    "MainDlgYSize        0",
    "MainDlgXPos         0",
    "MainDlgYPos         0",
    "FinderXSize         0",
    "FinderYSize         0",
    "FinderXPos          0",
    "FinderYPos          0",
    "#",
    "RecentUnit1          ",
    "RecentUnit2          ",
    "RecentUnit3          ",
    "RecentUnit4          ",
    "RecentUnit5          ",
    "RecentUnit6          ",
    "RecentUnit7          ",
    "RecentUnit8          "]
